data_list: List all data entries from config

View source: R/data_read.R

data_listR Documentation

List all data entries from config

Description

Lists all data specifications defined in the configuration, showing the data key, path, type, and description (if available).

Usage

data_list()

Value

A data frame with columns: name, path, type, locked, description

Examples


if (FALSE) {
# List all data entries
data_list()

# Use the alias
list_data()
}


framework documentation built on Feb. 18, 2026, 1:07 a.m.