data_read: Read data using dot notation path or direct file path

View source: R/data_read.R

data_readR Documentation

Read data using dot notation path or direct file path

Description

Supports CSV, TSV, RDS, Excel (.xlsx, .xls), Stata (.dta), SPSS (.sav, .zsav, .por), and SAS (.sas7bdat, .xpt) file formats.

Usage

data_read(path, delim = NULL, keep_attributes = FALSE, ...)

Arguments

path

Dot notation path (e.g. "source.private.example") or direct file path

delim

Optional delimiter for CSV files ("comma", "tab", "semicolon", "space")

keep_attributes

Logical flag to preserve special attributes (e.g., haven labels). Default: FALSE (strips attributes)

...

Additional arguments passed to read functions (readr::read_delim, readxl::read_excel, haven::read_*, etc.)

Value

The loaded data, typically a data frame or tibble.


framework documentation built on Feb. 18, 2026, 1:07 a.m.