db_drivers_status: Check if database drivers are installed

View source: R/drivers.R

db_drivers_statusR Documentation

Check if database drivers are installed

Description

Checks which database drivers are currently available on the system. Returns a data frame showing the status of all supported database drivers.

Usage

db_drivers_status(quiet = FALSE)

Arguments

quiet

Logical. If TRUE, suppresses messages. Default: FALSE

Value

A data frame with columns:

  • driver: Database driver name

  • package: Required R package

  • installed: Whether the package is installed

  • version: Package version (if installed)

Examples


# Check all drivers
db_drivers_status()

# Quiet mode (no messages)
db_drivers_status(quiet = TRUE)



framework documentation built on Feb. 18, 2026, 1:07 a.m.