db_list: List all database connections from configuration

View source: R/connections.R

db_listR Documentation

List all database connections from configuration

Description

Lists all database connections defined in the configuration, showing the connection name, driver, host, and database name (if applicable).

Usage

db_list()

Value

Invisibly returns NULL after printing connection list

Examples


if (FALSE) {
# List all connections
db_list()
}


framework documentation built on Feb. 18, 2026, 1:07 a.m.