dot-catalog_field_default: Retrieve a default value from the catalog, falling back when...

.catalog_field_defaultR Documentation

Retrieve a default value from the catalog, falling back when missing

Description

Retrieve a default value from the catalog, falling back when missing

Usage

.catalog_field_default(catalog, field_id, fallback = NULL)

framework documentation built on Feb. 18, 2026, 1:07 a.m.