dot-df_to_list_of_lists: Convert data frame to list of lists for YAML serialization...

.df_to_list_of_listsR Documentation

Convert data frame to list of lists for YAML serialization JSON arrays of objects become data frames in R, but YAML needs list of lists

Description

Convert data frame to list of lists for YAML serialization JSON arrays of objects become data frames in R, but YAML needs list of lists

Usage

.df_to_list_of_lists(df)

framework documentation built on Feb. 18, 2026, 1:07 a.m.