dot-framework_catalog_default_path: Get the path to the packaged settings catalog YAML

.framework_catalog_default_pathR Documentation

Get the path to the packaged settings catalog YAML

Description

Get the path to the packaged settings catalog YAML

Usage

.framework_catalog_default_path()

framework documentation built on Feb. 18, 2026, 1:07 a.m.