| .mark_scaffolded | R Documentation |
Mark project as scaffolded
.mark_scaffolded(project_root = NULL)
project_root |
Optional project root where the scaffold marker should be written. Falls back to the current working directory when NULL. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.