dot-migrate_config_from_previous: Migrate config from previous R versions or legacy location

.migrate_config_from_previousR Documentation

Migrate config from previous R versions or legacy location

Description

Checks for configs in legacy ~/.config/framework location and copies them to the current R_user_dir location if found.

Usage

.migrate_config_from_previous(target_dir)

Arguments

target_dir

Target config directory

Value

TRUE if migration occurred, FALSE otherwise


framework documentation built on Feb. 18, 2026, 1:07 a.m.