| .normalize_package_spec | R Documentation |
Converts the various package representations supported in settings.yml into a consistent structure that downstream helpers can rely on.
.normalize_package_spec(spec)
spec |
Character string or list describing a package dependency |
List with fields: name, source, version, repo, ref, auto_attach
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.