dot-s3_client: Create an S3 client from connection configuration

.s3_clientR Documentation

Create an S3 client from connection configuration

Description

Creates an S3 client object using credentials from the connection configuration. Credentials are resolved from connection config, falling back to environment variables. Loads .env file if present to ensure env vars are available.

Usage

.s3_client(conn_config)

Arguments

conn_config

List. Connection configuration from config.yml

Value

An S3 client object (from aws.s3 package)


framework documentation built on Feb. 18, 2026, 1:07 a.m.