dot-uses_split_file: Determine if a project field uses split file or inline...

.uses_split_fileR Documentation

Determine if a project field uses split file or inline settings

Description

Determine if a project field uses split file or inline settings

Usage

.uses_split_file(project_path, field_name)

Arguments

project_path

Path to project directory

field_name

Name of the field to check (e.g., "packages", "connections")

Value

List with use_split, main_file, split_file, and has_default


framework documentation built on Feb. 18, 2026, 1:07 a.m.