env_summary: Summarize R environment

View source: R/env.R

env_summaryR Documentation

Summarize R environment

Description

Displays a summary of the current R environment including loaded packages, objects in the global environment, and memory usage.

Usage

env_summary(envir)

Arguments

envir

The environment to summarize

Value

Invisibly returns a list with environment information

Examples


if (FALSE) {
env_summary(envir = my_env)
}


framework documentation built on Feb. 18, 2026, 1:07 a.m.