framework-package: framework: Structured Data Science Project Scaffolding

framework-packageR Documentation

framework: Structured Data Science Project Scaffolding

Description

Project scaffolding and workflow tools for reproducible data science. Manages packages, tracks data integrity, handles database connections, generates notebooks, and publishes to S3-compatible storage. More information at https://framework.table1.org.

Author(s)

Maintainer: Erik Westlund erik@table1.org [copyright holder]

See Also

Useful links:


framework documentation built on Feb. 18, 2026, 1:07 a.m.