git_status: Show Git Status

View source: R/git_hooks.R

git_statusR Documentation

Show Git Status

Description

Display the working tree status from the R console.

Usage

git_status(short = FALSE)

Arguments

short

Logical; if TRUE, show short format (default: FALSE)

Value

Invisibly returns the status output as a character vector

Examples


if (FALSE) {
git_status()
git_status(short = TRUE)
}



framework documentation built on Feb. 18, 2026, 1:07 a.m.