new_course: Create a Course Project

View source: R/new_project.R

new_courseR Documentation

Create a Course Project

Description

Shorthand for new_project(..., type = "course"). Creates a project structured for teaching materials with slides, assignments, and modules.

Usage

new_course(name = NULL, location = NULL, browse = interactive(), ...)

Arguments

name

Project name. If NULL (default), prompts interactively.

location

Directory path where project will be created. If NULL (default), prompts interactively.

browse

Whether to open the project folder after creation (default: TRUE in interactive sessions)

...

Additional arguments passed to 'project_

Value

Invisibly returns the result from project_create()

See Also

new_project()

Examples


if (FALSE) {
new_course("stats-101", "~/projects/stats-101")
}



framework documentation built on Feb. 18, 2026, 1:07 a.m.