| outputs | R Documentation |
First-class functions for saving tables, figures, models, and reports. These functions implement lazy directory creation with console feedback.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.