View source: R/quarto_generate.R
| quarto_generate_all | R Documentation |
Main entry point for generating all _quarto.yml files in a project.
Generates root config and directory-specific configs based on project type.
quarto_generate_all(
project_path,
project_type,
render_dirs = NULL,
quarto_settings = NULL,
directories = NULL,
root_output_dir = NULL
)
project_path |
Character. Path to project root |
project_type |
Character. One of "project", "project_sensitive", "course", "presentation" |
render_dirs |
Named list. Render directories with their paths |
quarto_settings |
List. Quarto settings (html and revealjs configs) |
directories |
Named list. Source directories keyed the same as render_dirs |
root_output_dir |
Optional output directory to set on the root _quarto.yml |
List with success status and paths of generated files
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.