View source: R/quarto_generate.R
| quarto_regenerate | R Documentation |
Regenerates all _quarto.yml files in a project.
WARNING: This will overwrite any manual edits.
Should only be called when user explicitly requests regeneration.
quarto_regenerate(project_path, backup = TRUE)
project_path |
Character. Path to project root |
backup |
Logical. If TRUE, backs up existing files before overwriting. Default TRUE. |
List with success status, backed up files, and regenerated files
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.