| reset_framework_template | R Documentation |
Reset a Framework template back to the packaged default
reset_framework_template(name)
name |
Template identifier (e.g., "notebook", "gitignore", "ai_claude") |
Invisibly returns the file path of the reset template.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.