scratch_clean: Clean up the scratch directory by deleting all files

View source: R/scratch.R

scratch_cleanR Documentation

Clean up the scratch directory by deleting all files

Description

Clean up the scratch directory by deleting all files

Usage

scratch_clean()

Value

Invisibly returns NULL. Called for side effect of removing scratch files.


framework documentation built on Feb. 18, 2026, 1:07 a.m.