| status | R Documentation |
Displays comprehensive information about the current Framework project including:
Framework package version
Project configuration
Git status
AI assistant configuration
Git hooks status
Package dependencies
Directory structure
status()
No return value, called for side effect of printing project status.
if (FALSE) {
status()
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.