| cache_list | R Documentation |
Returns a data frame of all cache entries with their names, expiration times, and status (expired or active).
cache_list()
A data frame with columns:
Cache key name
Expiration timestamp (NA if no expiration)
When the cache was created
When the cache was last updated
When the cache was last read
Either "active" or "expired"
Returns an empty data frame if no cache entries exist.
if (FALSE) {
# List all cache entries
cache_list()
# Filter to see only expired caches
cache_list() |> dplyr::filter(status == "expired")
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.