| data_list | R Documentation |
Lists all data specifications defined in the configuration, showing the data key, path, type, and description (if available).
data_list()
A data frame with columns: name, path, type, locked, description
if (FALSE) {
# List all data entries
data_list()
# Use the alias
list_data()
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.