| db_list | R Documentation |
Lists all database connections defined in the configuration, showing the connection name, driver, host, and database name (if applicable).
db_list()
Invisibly returns NULL after printing connection list
if (FALSE) {
# List all connections
db_list()
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.