| .df_to_list_of_lists | R Documentation |
Convert data frame to list of lists for YAML serialization JSON arrays of objects become data frames in R, but YAML needs list of lists
.df_to_list_of_lists(df)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.