| .s3_client | R Documentation |
Creates an S3 client object using credentials from the connection configuration. Credentials are resolved from connection config, falling back to environment variables. Loads .env file if present to ensure env vars are available.
.s3_client(conn_config)
conn_config |
List. Connection configuration from config.yml |
An S3 client object (from aws.s3 package)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.