| env_summary | R Documentation |
Displays a summary of the current R environment including loaded packages, objects in the global environment, and memory usage.
env_summary(envir)
envir |
The environment to summarize |
Invisibly returns a list with environment information
if (FALSE) {
env_summary(envir = my_env)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.