| get_global_setting | R Documentation |
Retrieve a specific setting from the global configuration file (~/.frameworkrc.json). This is a helper function primarily for use by the CLI script.
get_global_setting(key, default = "", print = TRUE)
key |
Character. The setting key to retrieve (e.g., "defaults.ide", "author.name") |
default |
Character. Default value if setting is not found (default: "") |
print |
Logical. If TRUE, prints the value (for bash consumption). Default TRUE. |
The setting value as a character string
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.