| git_diff | R Documentation |
Show changes between commits, working tree, etc.
git_diff(staged = FALSE, file = NULL)
staged |
Logical; if TRUE, show staged changes (default: FALSE shows unstaged) |
file |
Optional file path to show diff for specific file |
Invisibly returns the diff output as a character vector
if (FALSE) {
git_diff() # Show unstaged changes
git_diff(staged = TRUE) # Show staged changes
git_diff(file = "R/foo.R")
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.