| git_status | R Documentation |
Display the working tree status from the R console.
git_status(short = FALSE)
short |
Logical; if TRUE, show short format (default: FALSE) |
Invisibly returns the status output as a character vector
if (FALSE) {
git_status()
git_status(short = TRUE)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.