| new_course | R Documentation |
Shorthand for new_project(..., type = "course"). Creates a project
structured for teaching materials with slides, assignments, and modules.
new_course(name = NULL, location = NULL, browse = interactive(), ...)
name |
Project name. If NULL (default), prompts interactively. |
location |
Directory path where project will be created. If NULL (default), prompts interactively. |
browse |
Whether to open the project folder after creation (default: TRUE in interactive sessions) |
... |
Additional arguments passed to 'project_ |
Invisibly returns the result from project_create()
new_project()
if (FALSE) {
new_course("stats-101", "~/projects/stats-101")
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.