View source: R/project_create.R
| project_create | R Documentation |
Low-level function that creates a complete Framework project. This is called
by the GUI and by user-facing functions like new() and new_project().
Users should typically use new() instead.
project_create(
name,
location,
type = "project",
author = list(name = "", email = "", affiliation = ""),
packages = list(use_renv = FALSE, default_packages = list()),
directories = list(),
extra_directories = list(),
ai = list(enabled = FALSE, assistants = c(), canonical_content = ""),
git = list(use_git = TRUE, hooks = list(), gitignore_content = ""),
scaffold = list(seed_on_scaffold = FALSE, seed = "", set_theme_on_scaffold = TRUE,
ggplot_theme = "theme_minimal"),
connections = NULL,
env = NULL,
quarto = NULL,
render_dirs = NULL
)
name |
Project name (used for project title) |
location |
Full path to the project directory (will be created) |
type |
Project type: "project", "project_sensitive", "course", "presentation" |
author |
List with name, email, affiliation |
packages |
List with use_renv (logical) and default_packages (list of package configs) |
directories |
Named list of directory paths (notebooks, scripts, functions, etc.) |
extra_directories |
List of additional custom directories |
ai |
List with enabled, assistants, canonical_content |
git |
List with use_git, hooks, gitignore_content |
scaffold |
List with seed_on_scaffold, seed, set_theme_on_scaffold, ggplot_theme, ide, positron |
quarto |
List with html and revealjs format configurations for Quarto |
render_dirs |
Named list of render directory paths for Quarto outputs |
List with success status, project path, and project ID
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.